@@ -6,7 +6,7 @@ use Carp;
 use JSON;
 use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Exporter qw(import);
  
@@ -141,7 +141,8 @@ Data::QuickMemoPlus::Reader - Extract text from QuickMemo+ LQM export files.
 =head1 DESCRIPTION
 
 C<Data::QuickMemoPlus::Reader> is a module that will extract the 
-text contents from archived QuickMemo+ memos.
+text contents from archived QuickMemo+ memos. QuickMemo+ is a memo 
+application that comes with LG smartphones.
 
 QuickMemo+ F<lqm> files are in Zip format. This module unzips them, 
 parses the json file inside, then extracts the category and memo text 
